package com.faraphel.tasks_valider.ui.screen.communication.internet

import android.app.Activity
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.text.input.KeyboardType
import com.faraphel.tasks_valider.connectivity.task.TaskClient
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_ADDRESS
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.communication.RANGE_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.task.TaskSessionScreen


@Composable
fun CommunicationInternetClientScreen(activity: Activity) {
    val client = remember { mutableStateOf<TaskClient?>(null) }

    if (client.value == null) CommunicationInternetClientContent(client)
    else TaskSessionScreen(activity, client.value!!)
}


@Composable
fun CommunicationInternetClientContent(client: MutableState<TaskClient?>) {
    val serverAddress = remember { mutableStateOf(DEFAULT_SERVER_ADDRESS) }
    val serverPort = remember { mutableIntStateOf(DEFAULT_SERVER_PORT) }

    Column {
        // server address
        TextField(
            value = serverAddress.value,
            onValueChange = { text ->
                serverAddress.value = text
            }
        )

        // server port
        TextField(
            value = serverPort.intValue.toString(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            onValueChange = { text ->
                val port = text.toInt()
                if (port in RANGE_SERVER_PORT) {
                    serverPort.intValue = port
                }
            }
        )

        Button(onClick = {
            // TODO(Faraphel): check if the server is reachable
            client.value = TaskClient(serverAddress.value, serverPort.intValue)
        }) {
            Text("Connect")
        }
    }
}