package com.faraphel.tasks_valider.ui.screen.communication.internet

import android.app.Activity
import android.util.Log
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.text.input.KeyboardType
import androidx.room.Room
import com.faraphel.tasks_valider.connectivity.task.TaskClient
import com.faraphel.tasks_valider.connectivity.task.TaskServer
import com.faraphel.tasks_valider.database.TaskDatabase
import com.faraphel.tasks_valider.database.entities.ClassEntity
import com.faraphel.tasks_valider.database.entities.PersonEntity
import com.faraphel.tasks_valider.database.populateTaskDatabaseTest
import com.faraphel.tasks_valider.ui.screen.authentification.AuthentificationServerScreen
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.communication.RANGE_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.task.TaskSessionScreen


/**
 * Screen for the host to configure the server
 */
@Composable
fun CommunicationInternetServerScreen(activity: Activity) {
    val adminPersonEntity = remember { mutableStateOf<PersonEntity?>(null) }

    // if the admin person is not created, prompt the user for the admin information
    if (adminPersonEntity.value == null) {
        return AuthentificationServerScreen(adminPersonEntity)
    }

    val client = remember { mutableStateOf<TaskClient?>(null) }

    // if the client to the server is not created, prompt the user for the server configuration
    if (client.value == null) {
        return CommunicationInternetServerContent(
            activity,
            adminPersonEntity.value!!,
            client
        )
    }

    // otherwise, go to the base tasks screen
    return TaskSessionScreen(activity, client.value!!)
}


@Composable
fun CommunicationInternetServerContent(
    activity: Activity,
    adminPersonEntity: PersonEntity,
    client: MutableState<TaskClient?>
) {
    val expandedStudentList = remember { mutableStateOf(false) }
    val serverPort = remember { mutableIntStateOf(DEFAULT_SERVER_PORT) }

    Column {
        // student list
        Button(onClick = { expandedStudentList.value = !expandedStudentList.value }) {
            Text(text = "Select Students List")
        }
        DropdownMenu(
            expanded = expandedStudentList.value,
            onDismissRequest = { expandedStudentList.value = false }
        ) {
            // TODO(Faraphel): student lists should be loaded from the database or a file
            DropdownMenuItem(
                text = { Text("ISRI") },
                onClick = {}
            )
            DropdownMenuItem(
                text = { Text("MIAGE") },
                onClick = {}
            )
        }

        // server port
        TextField(
            value = serverPort.intValue.toString(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            onValueChange = { text ->
                val port = text.toInt()
                if (port in RANGE_SERVER_PORT) {
                    serverPort.intValue = port
                }
            }
        )

        Button(onClick = {
            Thread {  // a thread is used for networking
                // Reset the database | TODO(Faraphel): only for testing purpose
                activity.deleteDatabase("local")

                // Create the database
                val database = Room.databaseBuilder(
                    activity,
                    TaskDatabase::class.java,
                    "local"
                ).build()

                // Populate the database with test data
                // TODO(Faraphel): remove test data
                populateTaskDatabaseTest(database)

                // Insert the admin in the database
                database.personDao().insert(adminPersonEntity)

                // Create the server
                Log.i("room-server", "creating the server")
                val server = TaskServer(serverPort.intValue, database, adminPersonEntity)
                server.start()

                // Get the client from the server
                client.value = server.getAdminClient()
            }.start()
        }) {
            Text("Create")
        }
    }
}
